from http import HTTPStatus
import json
import requests

token = 'secret_1i1MgE6QzwiUtHlCuwhfBRIP8ni2uZcfGTCpsEu2TE7'
database_id = 'aecca5271bb84731b1569afc1f8efa9a'

headers = {
    "Authorization": "Bearer " + token,
    "Content-Type": "application/json",
    "Notion-Version": "2022-06-28"
}

def createRecipe(coverPhotoUrl, cookingTime, websiteName, recipeUrl, recipeTitle, ingredients, instructions):
   print("Building Notion API request")
   payload = {
   "parent": {
      "database_id": database_id
   },
   "cover": {
      "type": "external",
      "external": {
         "url": coverPhotoUrl
      }
   },
   "properties": {
      "Cook Time ⏰ ": {
         "type": "rich_text",
         "rich_text": [
            {
               "type": "text",
               "text": {
                  "content": cookingTime
               }
            }
         ]
      },
      "Website 💻 ": {
         "type": "rich_text",
         "rich_text": [
            {
               "type": "text",
               "text": {
                  "content": websiteName
               }
            }
         ]
      },
      "Link 🔗": {
         "type": "url",
         "url": recipeUrl
      },
      "Recipe Name 🔠": {
         "type": "title",
         "title": [
            {
               "type": "text",
               "text": {
                  "content": recipeTitle
               }
            }
         ]
      }
   },
   "children": [
      {
         "object": "block",
         "type": "column_list",
         "column_list": {
            "children": [
               {
                  "object": "block",
                  "type": "column",
                  "column": {
                     "children": [
                        {
                           "type": "heading_1",
                           "heading_1": {
                              "rich_text": [
                                 {
                                    "type": "text",
                                    "text": {
                                       "content": "🥘 Ingredients"
                                    }
                                 }
                              ],
                              "color": "default"
                           }
                        }
                     ]
                  }
               },
               {
                  "object": "block",
                  "type": "column",
                  "column": {
                     "children": [
                        {
                           "type": "heading_1",
                           "heading_1": {
                              "rich_text": [
                                 {
                                    "type": "text",
                                    "text": {
                                       "content": "🖊 Instructions"
                                    }
                                 }
                              ],
                              "color": "default"
                           }
                        },
                        {
                           "type": "paragraph",
                           "paragraph": {
                              "rich_text": [
                                 {
                                    "type": "text",
                                    "text": {
                                       "content": instructions
                                    }
                                 }
                              ],
                              "color": "default"
                              }
                           }
                        ]
                     }
                  }
               ]
            }
         }
      ]
   }

   for ingredient in ingredients:
      payload["children"][0]["column_list"]["children"][0]["column"]["children"].append(
      {
            "type": "bulleted_list_item",
            "bulleted_list_item": {
               "rich_text": [{
               "type": "text",
               "text": {
                  "content": ingredient
               }
               }]
            }
      },
   )

   print("API payload successfully created")
   print("Beginning API call")

   url = "https://api.notion.com/v1/pages"
   r = requests.post(url, data=json.dumps(payload), headers=headers)

   if(r.status_code == HTTPStatus.CREATED or r.status_code == HTTPStatus.OK):
      print("Notion API returned a successful response")
   elif(r.status_code == HTTPStatus.INTERNAL_SERVER_ERROR):
      print("Notion API returned a 500 error")
      print(r.text)
   else:
      print("Response code of " + str(r.status_code) + "returned from Notion API")
      print(r.text)

   return r.status_code


from http import HTTPStatus
from recipe_scrapers import scrape_me
import notion
import sys

if len(sys.argv) <= 1:
    print('No recipe URL passed as a parameter, re-run with a valid recipe link.')
    exit(1)
else:
    recipeUrl = sys.argv[1]

def startNotriton(recipeUrl):
    try:
        scraper = scrape_me(recipeUrl, wild_mode=True)
    except Exception as e:
        print("The website the recipe is from isn't supported right now.")
        exit(1)

    print("Website scraped successfully.")

    response = notion.createRecipe(scraper.image(), str(scraper.total_time()), scraper.site_name(), scraper.canonical_url(), scraper.title(), scraper.ingredients(), scraper.instructions())

    if(response == HTTPStatus.CREATED or response == HTTPStatus.OK):
        print(scraper.title() + " recipe from " + scraper.site_name() + " successfully added to Notion!")
    else:
        print("Error creating recipe: " + recipeUrl)

startNotriton(recipeUrl)